@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 # Let the "tail" commands work on fussy new posix systems
 _POSIX2_VERSION=199209
@@ -239,7 +239,9 @@ timewait 2
 echo
 echo Setting Perl5 search path
 echo
-PERL5LIB=`$PERL -V | grep site_perl | grep -v config_args | tr -d ' ' | tr '\n' ':'`
+#PERL5LIB=`$PERL -V | grep site_perl | grep -v config_args | tr -d ' ' | tr '\n' ':'`
+#export PERL5LIB
+PERL5LIB=`./getPERLLIB`
 export PERL5LIB
 
 if [ "x$NOMODULES" = "x" ]; then
@@ -271,43 +273,46 @@ if [ "x$NOMODULES" = "x" ]; then
     fi
   done << EOF
 File::Spec	File-Spec	0.82	1	yes	noarch
-ExtUtils::MakeMaker ExtUtils-MakeMaker 6.32 1	yes	noarch
-Net::CIDR	Net-CIDR	0.11	1	yes	noarch
+ExtUtils::MakeMaker ExtUtils-MakeMaker 6.50 2	yes	noarch
 IsABundle	IO-stringy	2.110	1	yes	noarch
 MIME::Base64	MIME-Base64	3.07	5	yes	i386
 IsABundle	TimeDate	1.16	3	yes	noarch
 Pod::Escapes    Pod-Escapes     1.04    1	yes	noarch
 Pod::Simple     Pod-Simple      3.05    1       yes	noarch
 Test::Harness	Test-Harness	2.64	1	yes	noarch
-Test::Simple	Test-Simple	0.70	1	no	noarch
+Test::Simple	Test-Simple	0.86	1	no	noarch
 Test::Pod       Test-Pod        1.26    1       yes	noarch
 IsABundle	MailTools	2.04	1	yes	noarch
 IO		IO		1.2301	1	yes	noarch
 File::Temp	File-Temp	0.20	1	yes	noarch
 HTML::Tagset	HTML-Tagset	3.03	1	yes	noarch
-HTML::Parser	HTML-Parser	3.56	1	yes	i386
+HTML::Parser	HTML-Parser	3.64	1	yes	i386
 IsABundle	MIME-tools	5.427	1	yes	noarch
 Convert::TNEF	Convert-TNEF	0.17	1	yes	noarch
 Compress::Zlib	Compress-Zlib	1.41	1	yes	i386
-Archive::Zip	Archive-Zip	1.16	1	yes	noarch
+Compress::Raw::Zlib	Compress-Raw-Zlib	2.027	1	yes	noarch
+Archive::Zip	Archive-Zip	1.30	1	yes	noarch
 Convert::BinHex	Convert-BinHex	1.119	2	no	noarch
 Scalar::Util	Scalar-List-Utils 1.19	1	yes	noarch
 Storable	Storable	2.16	1	yes	noarch
-DBI		DBI		1.56	1	yes	noarch
-DBD::SQLite	DBD-SQLite	1.13	1	yes	noarch
-Getopt::Long	Getopt-Long	2.36	1	yes	noarch
+DBI		DBI		1.607	1	yes	noarch
+DBD::SQLite	DBD-SQLite	1.25	1	yes	noarch
+Getopt::Long	Getopt-Long	2.38	1	yes	noarch
 Time::HiRes	Time-HiRes	1.9707	1	yes	noarch
 Filesys::Df	Filesys-Df	0.90	1	yes	noarch
-Math::BigInt	Math-BigInt	1.86	1	yes	noarch
-Math::BigRat	Math-BigRat	0.19	1	yes	noarch
-bignum		bignum		0.21	1	yes	noarch
+Math::BigInt	Math-BigInt	1.89	2	yes	noarch
+Math::BigRat	Math-BigRat	0.22	1	yes	noarch
+bignum		bignum		0.23	1	yes	noarch
+Net::CIDR	Net-CIDR	0.13	1	yes	noarch
 Net::IP		Net-IP		1.25	1	yes	noarch
 Sys::Hostname::Long Sys-Hostname-Long 1.4 1	yes	noarch
-Sys::Syslog	Sys-Syslog	0.18	1	yes	noarch
+Sys::Syslog	Sys-Syslog	0.27	1	yes	noarch
 Digest::MD5	Digest-MD5	2.36	1	yes	noarch
 Digest::SHA1	Digest-SHA1	2.11	1	yes	noarch
-Net::DNS	Net-DNS		0.63	1	yes	noarch
+Digest::HMAC	Digest-HMAC	1.01	1	yes	noarch
+Net::DNS	Net-DNS		0.65	1	yes	noarch
 OLE::Storage_Lite OLE-Storage_Lite 0.16	1	yes	noarch
+Sys::SigAction	Sys-SigAction	0.11	1	yes	noarch
 EOF
 
 else
@@ -363,16 +368,32 @@ if [ "x$SADIR" = "x" ]; then
   echo No SpamAssassin installation found.
 else
   if [ -d /opt/MailScanner/etc ]; then
-    ln -s -f /opt/MailScanner/etc/spam.assassin.prefs.conf ${SADIR}/mailscanner.cf
+    if [ -e ${SADIR}/mailscanner.cf ]; then
+      echo Leaving mailscanner.cf link or file alone.
+    else
+      ln -s -f /opt/MailScanner/etc/spam.assassin.prefs.conf ${SADIR}/mailscanner.cf
+    fi
     echo Good, the link was created to /opt/MailScanner/etc
   elif [ -d /usr/local/MailScanner/etc ]; then
-    ln -s -f /usr/local/MailScanner/etc/spam.assassin.prefs.conf ${SADIR}/mailscanner.cf
+    if [ -e ${SADIR}/mailscanner.cf ]; then
+      echo Leaving mailscanner.cf link or file alone.
+    else
+      ln -s -f /usr/local/MailScanner/etc/spam.assassin.prefs.conf ${SADIR}/mailscanner.cf
+    fi
     echo Good, the link was created to /usr/local/MailScanner/etc
   elif [ -d /etc/MailScanner ]; then
-    ln -s -f /etc/MailScanner/spam.assassin.prefs.conf ${SADIR}/mailscanner.cf
+    if [ -e ${SADIR}/mailscanner.cf ]; then
+      echo Leaving mailscanner.cf link or file alone.
+    else
+      ln -s -f /etc/MailScanner/spam.assassin.prefs.conf ${SADIR}/mailscanner.cf
+    fi
     echo Good, the link was created to /etc/MailScanner
   elif [ -d /usr/local/etc/MailScanner ]; then
-    ln -s -f /usr/local/etc/MailScanner/spam.assassin.prefs.conf ${SADIR}/mailscanner.cf
+    if [ -e ${SADIR}/mailscanner.cf ]; then
+      echo Leaving mailscanner.cf link or file alone.
+    else
+      ln -s -f /usr/local/etc/MailScanner/spam.assassin.prefs.conf ${SADIR}/mailscanner.cf
+    fi
     echo Good, the link was created to /usr/local/etc/MailScanner
   else
     echo
