@@ -268,12 +268,14 @@ mailscannerinstall () {
   # Create the spool directories if there aren't already signs of them
   if [ \! -d /var/spool/MailScanner ]; then
     mkdir -p /var/spool/MailScanner/incoming
+    mkdir -p /var/spool/MailScanner/incoming/Locks
     mkdir -p /var/spool/MailScanner/quarantine
     mkdir -p /var/spool/mqueue.in
     chown root /var/spool/mqueue.in
     chgrp bin  /var/spool/mqueue.in
     chmod u=rwx,g=rx,o-rwx /var/spool/mqueue.in
     chmod a+rx /var/spool/MailScanner/incoming
+    chmod a+rx /var/spool/MailScanner/incoming/Locks
     echo It looks like this is your first MailScanner installation so I have
     echo created the working directories and quarantine for you in /var/spool.
   fi
