@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ConfigDefs.pl 4713 2009-04-01 16:07:04Z sysjkf $
+#   $Id: ConfigDefs.pl 5062 2010-11-09 21:56:06Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -50,14 +50,14 @@ __DATA__
 
 [Translation,Translation]
 
-AFilenameRules			= ArchivesFilenameRules
-AFiletypeRules			= ArchivesFiletypeRules
-aallowfilenames			= ArchivesAllowFilenames
-adenyfilemimetypes		= ArchivesDenyFileMIMETypes
-adenyfiletypes			= ArchivesDenyFiletypes
-aallowfilemimetypes		= ArchivesAllowFileMIMETypes
-aallowfiletypes			= ArchivesAllowFiletypes
-adenyfilenames			= ArchivesDenyFilenames
+AFilenameRules                  = ArchivesFilenameRules
+AFiletypeRules                  = ArchivesFiletypeRules
+aallowfilenames                 = ArchivesAllowFilenames
+adenyfilemimetypes              = ArchivesDenyFileMIMETypes
+adenyfiletypes                  = ArchivesDenyFiletypes
+aallowfilemimetypes             = ArchivesAllowFileMIMETypes
+aallowfiletypes                 = ArchivesAllowFiletypes
+adenyfilenames                  = ArchivesDenyFilenames
 addenvfrom			= AddEnvelopeFromHeader
 addenvto			= AddEnvelopeToHeader
 addmshmac			= AddWatermark
@@ -132,6 +132,7 @@ includespamheader		= alwaysincludespamassassinreport
 includemcpheader		= alwaysincludemcpreport
 infoheader			= informationheader
 infovalue			= informationheadervalue
+insistpasszips			= ArchivesMustBePasswordProtected
 inlinehtmlsig			= inlinehtmlsignature
 inlinehtmlwarning		= inlinehtmlwarning
 inlinetextsig			= inlinetextsignature
@@ -178,9 +179,9 @@ phishinghighlight		= highlightphishingfraud
 phishingnumbers			= alsofindnumericphishing
 phishingsubjecttag		= phishingsubjecttext
 phishingwhitelist		= phishingsafesitesfile
-procdbattempts			= MaximumProcessingAttempts
-procdbname			= ProcessingAttemptsDatabase
 outqueuedir			= outgoingqueuedir
+procdbattempts			= maximumprocessingattempts
+procdbname			= processingattemptsdatabase
 quarantinesilent		= quarantinesilentviruses
 quarantineuser			= quarantineuser
 quarantinegroup			= quarantinegroup
@@ -218,6 +219,7 @@ mcpmodifysubject		= mcpmodifysubject
 sizemodifysubject		= sizemodifysubject
 sizesubjecttext			= sizesubjecttext
 spamassassintempdir		= spamassassintemporarydir
+spaminfected			= VirusNamesWhichAreSpam
 spammodifysubject		= spammodifysubject
 spamscorenotstars		= spamscorenumberinsteadofstars
 spamstars			= spamscore
@@ -242,6 +244,10 @@ unpackole			= UnpackMicrosoftDocuments
 unscannedheader			= unscannedheadervalue
 usedefaultswithmanyrecips       = usedefaultruleswithmultiplerecipients
 tagphishingsubject		= phishingmodifysubject
+unzipmaxmembers			= UnzipMaximumFilesPerArchive
+unzipmaxsize			= UnzipMaximumFileSize
+unzipmembers			= UnzipFilenames
+unzipmimetype			= UnzipMimeType
 #virusbeforespammcp		= virusscanningbeforespamormcp
 virusmodifysubject		= virusmodifysubject
 virusscan			= virusscanning
@@ -275,7 +281,6 @@ clamavspam		0	no	0	yes	1
 debug			0	no	0	yes	1
 debugspamassassin	0	no	0	yes	1
 deliverinbackground	1	no	0	yes	1
-getipfromheader		0	no	0	yes	1
 logdelivery		0	no	0	yes	1
 lognonspam		0	no	0	yes	1
 logsaactions		0	no	0	yes	1
@@ -292,6 +297,7 @@ storeentireasdfqf	0	no	0	yes	1
 syntaxcheck		1	no	0	yes	1
 usedefaultswithmanyrecips	0	no	0	yes	1
 #virusbeforespammcp	0	no	0	yes	1
+SQLDebug		0	no	0	yes	1
 
 # These should be checked for dir existence
 [Simple,Dir]
@@ -358,6 +364,7 @@ ClamWatchFiles		/usr/local/share/clamav/*.cvd
 CustomFunctionsDir	/usr/lib/MailScanner/MailScanner/CustomFunctions
 FileCommand		/usr/bin/file
 FirstCheck		mcp
+getipfromheader		0
 GunzipCommand		/bin/gunzip
 inqueuedir		/var/spool/mqueue.in
 LDAPbase
@@ -389,6 +396,7 @@ SpamAssassinLocalRulesDir
 SpamAssassinLocalStateDir	
 SpamAssassinDefaultRulesDir	
 SpamAssassinInstallPrefix	
+SpamInfected		Sane*UNOFFICIAL
 SpamStarsCharacter	s
 MCPMaxSpamAssassinSize		100000
 MCPSpamAssassinUserStateDir
@@ -401,6 +409,14 @@ VirusScanners		auto  # Space-separated list
 WorkUser
 WorkGroup
 WorkPerms		0600
+DBDSN
+DBUsername
+DBPassword
+SQLSerialNumber
+SQLQuickPeek
+SQLConfig
+SQLRuleset
+SQLSpamAssassinConfig
 
 #
 # These variables match on any rule matching From:, else anything for To:
@@ -443,6 +459,7 @@ LookForUU		0	no	0	yes	1
 MultipleHeaders		append	append	append	replace	replace	add	add
 NameModifySubject	start	no	0	yes	1	start	start	end	end
 NoticeFullHeaders	1	no	0	yes	1
+RejectMessage		0	no	0	yes	1
 ScannedModifySubject	0	no	0	yes	1	start	start	end	end
 SendNotices		1	no	0	yes	1
 SignAlreadyScanned	0	no	0	yes	1
@@ -530,10 +547,12 @@ MinStars			0
 mshmacvalid			604800
 NormalRBLs			1
 ReqSpamAssassinScore		6
+unzipmaxmembers			0
+unzipmaxsize			50000
 
 [First,Other]
 Antiword			/usr/bin/antiword -f
-ArchivesAre			zip rar uu ole tnef
+ArchivesAre			zip rar ole
 AttachmentCharset		ISO-8859-1
 attachimageinternalname
 attachimagename
@@ -541,6 +560,7 @@ AttachmentWarningFilename	VirusWarning.txt
 AttachZipName			MessageAttachments.zip
 cleanheader			Found to be clean
 ContentSubjectText		{Dangerous Content?}
+DefaultRenamePattern		__FILENAME__.disarmed
 dirtyheader			Found to be infected
 DisarmSubjectText		{Disarmed}
 DisinfectedHeader		Disinfected
@@ -566,6 +586,7 @@ ScoreFormat			%d
 Sendmail2			/usr/sbin/sendmail
 SpamHeader			X-MailScanner-SpamCheck:
 SpamList
+SpamVirusHeader			X-MailScanner-SpamVirus-Report:
 MCPSubjectText			{MCP?}
 SpamSubjectText			{Spam?}
 SpamStarsHeader			X-MailScanner-SpamScore:
@@ -580,6 +601,8 @@ NonMCPActions		deliver
 MCPActions		deliver
 HighScoreMCPActions	deliver
 SizeSubjectText		{Size}
+unzipmembers		*.txt *.ini *.log *.csv
+unzipmimetype		text/plain
 
 [All,YesNo]
 AddEnvFrom		1	no	0	yes	1
@@ -607,16 +630,16 @@ FindPhishing		1	no	0	yes	1
 markinfectedmessages	1	no	0	yes	1
 PhishingHighlight	1	no	0	yes	1
 HtmlToText		0	no	0	yes	1
+InsistPassZips		0	no	0	yes	1
 NewHeadersAtTop		0	no	0	yes	1
 PhishingNumbers		1	no	0	yes	1
 QuarantineInfections	1	no	0	yes	1
 QuarantineModifiedBody	0	no	0	yes	1
 QuarantineSilent	0	no	0	yes	1
 QuarantineWholeMessage	0	no	0	yes	1
-RejectMessage		0	no	0	yes	1
 ReplaceTNEF		2	no	0	add	1	replace	2
 sadecodebins		0	no	0	yes	1
-ScanMail		1	no	0	yes	1
+ScanMail		1	no	0	yes	1	virus	2
 SpamStars		1	no	0	yes	1
 StrictPhishing          1       no      0       yes     1
 TagPhishingSubject	0	no	0 	yes	1	start	start	end	end
@@ -632,14 +655,14 @@ ZipAttachments		0	no	0	yes	1
 [All,Other]
 # This is the other stuff that came up in the search that I haven't
 # figured out what to do with yet...
-AFilenameRules
-AFiletypeRules
 aallowfilenames
 adenyfilemimetypes
 adenyfiletypes
 aallowfilemimetypes
 aallowfiletypes
 adenyfilenames
+afilenamerules
+afiletyperules
 ArchiveMail
 AttachZipIgnore			.zip .rar .gz .tgz .mpg .mpe .mpeg .mp3 .rpm
 ClamdLockFile
