@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: TNEF.pm 4520 2008-08-20 11:13:32Z sysjkf $
+#   $Id: TNEF.pm 5102 2011-08-20 12:31:59Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -36,12 +36,13 @@ use strict 'refs';
 no  strict 'subs'; # Allow bare words for parameter %'s
 
 use DirHandle;
+use File::Temp qw/ tempfile tempdir /;
 use POSIX qw(:signal_h setsid); # For Solaris 9 SIG bug workaround
 
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4520 $, 10;
+$VERSION = substr q$Revision: 5102 $, 10;
 
 my($UseTNEFModule) = 0;
 
@@ -73,35 +74,40 @@ sub new {
 
 
 # Look through an entity to find a TNEF file. Recursive.
+# Returns a list of the entity and the real filename with type indicator
 sub FindTNEFFile {
   my($entity) = @_;
 
-  my(@parts, $body, $part, $path, $headfile, $tnef);
+  my(@parts, $body, $part, $path, $headfile, $tnef, $filename);
 
   # Find the body for this entity
   return undef unless $entity;
   $body = $entity->bodyhandle;
   if (defined($body) && defined($body->path)) {   # data is on disk:
     $path = $body->path;
-    return $entity if $path =~ /winmail\d*\.dat\d*$/i;
+    $filename = $path;
+    $filename =~ s#^.*/([^/]+)$#$1#;
+    return ($entity,$filename) if $filename =~ /winmail\d*\.dat\d*$/i;
     #$path =~ s#^.*/([^/]*)$#$1#;
   }
   # And the head, which is where the recommended filename is stored
   # This is so we can report infections in the filenames which are
   # recommended, even if they are evil and we hence haven't used them.
   $headfile = $entity->head->recommended_filename;
-  return $entity
-    if (defined($headfile) && $headfile =~ /winmail\d*\.dat\d*$/i);
+  $filename = $headfile;
+  $filename =~ s#^.*/([^/]+)$#$1#;
+  return ($entity,$filename)
+    if (defined($filename) && $filename =~ /winmail\d*\.dat\d*$/i);
 
   # And for all its children
   @parts = $entity->parts;
   foreach $part (@parts) {
-    $tnef = FindTNEFFile($part);
-    return $tnef if defined($tnef);
+    ($tnef,$filename) = FindTNEFFile($part);
+    return ($tnef,$filename) if defined($tnef);
   }
 
   # Must return something.
-  return undef;
+  return (undef,undef);
 }
 
 
@@ -112,8 +118,15 @@ sub FindTNEFFile {
 sub Decoder {
   my($dir, $tnefname, $message) = @_;
 
-  return InternalDecoder($dir, $tnefname, $message) if $UseTNEFModule;
-  return ExternalDecoder($dir, $tnefname, $message);
+  my $perms = $global::MS->{work}->{fileumask} ^ 0777;
+  my $owner = $global::MS->{work}->{uid};
+  my $group = $global::MS->{work}->{gid};
+  my $change= $global::MS->{work}->{changeowner};
+
+  return InternalDecoder($dir, $tnefname, $message,
+                         $perms, $owner, $group, $change) if $UseTNEFModule;
+  return ExternalDecoder($dir, $tnefname, $message,
+                         $perms, $owner, $group, $change);
 }
 
 
@@ -121,80 +134,85 @@ sub Decoder {
 # Use the internal TNEF module.
 # Return 1 on success, 0 on failure.
 sub InternalDecoder {
-  my($dir, $tnefname, $message) = @_;
-  my($fh, $filename, %parms);
+  my($dir, $tnefname, $message, $perms, $owner, $group, $change) = @_;
+  my($fh, %parms);
 
   # Make the temporary tnef files be created under /tmp for easy removal.
-  mkdir "/tmp/tnef.$$", 0777;
-  chmod 0700, "/tmp/tnef.$$";
+  my $tempdir = tempdir();
+  chmod 0700, $tempdir;
   %parms = ( ignore_checksum => "true",
-             output_dir      => "/tmp/tnef.$$",
+             output_dir      => $tempdir,
              output_to_core  => "NONE" );
   my $tnef = Convert::TNEF->read_in("$dir/$tnefname", \%parms);
+
   if ($tnef) {
     #print STDERR "Parsing returned something\n";
     #print STDERR "Attachment list is \"" . $tnef->attachments . "\"\n";
     #print STDERR "List is \"" . join('","', @{$tnef->attachments}) . "\"\n";
-    $message->{entity}->make_multipart;
     my $addcontents = 0;
     $addcontents = 1
       if MailScanner::Config::Value('replacetnef',$message) =~ /[12]/;
+    $message->{entity}->make_multipart if $addcontents;
 
-    my($safename, @replacements);
-    foreach $_ (@{$tnef->attachments}) {
-      #print STDERR "Doing attachment $_\n";
-      if (my $handle = $_->datahandle) {
-        #print STDERR "Have a datahandle $handle\n";
-        # There is a method to get the filename from the attachment,
-        # but it of course is tainted (and you might end up overwriting
-        # attachments with the same name within the same file)
-        # so you might just want to generate
-        # your own temp file name or use File::Temp
-        ($fh, $filename) = File::Temp::tempfile(DIR => $dir);
-        #print STDERR "Tempfile = $fh, $filename\ndir = $dir\n";
-        $message->{file2parent}{$filename} = $tnefname;
-        if (defined(my $file = $handle->path)) {
-          $message->{file2parent}{$file} = $tnefname;
-          File::Copy::copy($file, $fh)
-            or MailScanner::Log::DieLog("Can't copy $file to $filename: $!");
-        } else {
-          print $fh $handle->as_string;
-        }
-        close($fh);
+    my($safename, $handle, @replacements, $attachname);
+    foreach $attachname (@{$tnef->attachments}) {
+      #print STDERR "Doing attachment $attachname\n";
+      #print STDERR "Have a datahandle $handle\n";
+      # There is a method to get the filename from the attachment,
+      # but it of course is teinted (and you might end up overwriting
+      # attachments with the same name within the same file)
+      # so you might just want to generate
+      # your own temp file name or use File::Temp
+      # Make sure the temp file we create starts with a 't' as this is a
+      # file extracted from a tnef archive.
+      #($fh, $filename) = File::Temp::tempfile("tTNEFattachmentXXXXX",
+      #                                        DIR => $dir,
+      #                                        UNLINK => 0);
+      # file2parent must not contain the leading 't'.
+      $safename = $message->MakeNameSafe('t'.($attachname->longname), $dir);
+      #print STDERR "Tempfile = $safename\n";
+      $message->{file2parent}{substr($safename,1)} = $tnefname;
+      $message->{file2parent}{$safename} = $tnefname; # For good measure!
+      $handle = $attachname->datahandle;
+      my $tmpnam1 = "$dir/$safename";
+      $tmpnam1 =~ /^(.*)$/;
+      $tmpnam1 = $1;
+      if ($handle && defined(my $file = $handle->path)) {
+        rename($file, $tmpnam1);
+        # JKF 20090421 CHMOD, then CHOWN and CHGRP it if necessary.
+        chmod $perms, $tmpnam1;
+        chown $owner, $group, $tmpnam1 if $change;
+        #print STDERR "Moved $file to $safename\n";
+      }
+      #close($fh);
 
-        if ($addcontents) {
-          # Add the member file to the list of attachments in the message
-          #print STDERR "Reading attachment from \"" . $_->name .
-          #             "\" and \"" . $_->longname . "\"\n";
-          #print STDERR "Attachment \"$filename\" --> \"" .
-          #             $_->longname . "\"\n";
-          # Save the new names for logging
-          $safename = $message->MakeNameSafe($_->longname, $dir);
-          push @replacements, $safename;
-          #print STDERR "Safe name is \"$safename\"\n";
-          $message->{entity}->attach(Type => "application/octet-stream",
-                                     Encoding => "base64",
-                                     Disposition => "attachment",
-                                     Filename => $_->longname,
-                                     Path => $filename);
-          $message->{bodymodified} = 1;
-          #print STDERR "Message = $message and Message ID = " . $message->{id} . "\n";
-        }
+      if ($addcontents) {
+        # Add the member file to the list of attachments in the message
+        # The safe filename will have a 't' for TNEF at the front.
+        #$safename = $message->MakeNameSafe($attachname->longname, $dir);
+        push @replacements, substr($safename,1); # Without the type
+        $message->{entity}->attach(Type => "application/octet-stream",
+                                   Encoding => "base64",
+                                   Disposition => "attachment",
+                                   Filename => $attachname->longname,
+                                   Path => $tmpnam1); # Has type
+        $message->{bodymodified} = 1;
       }
     }
-    $tnef->purge;
+    $tnef->purge unless $addcontents;
     undef $tnef;
     $message->{foundtnefattachments} = 1;
     #$message->{entity}->dump_skeleton();
-    system("rm -rf /tmp/tnef.$$");
+    system("rm -rf $tempdir"); # /tmp/tnef.$$");
     MailScanner::Log::InfoLog("Message %s added TNEF contents %s",
-                              $message->{id}, join(',', @replacements))
+                              $message->{id},
+                              join(',', @replacements))
       if @replacements;
     return 1;
   } else {
     # It failed
     undef $tnef;
-    system("rm -rf /tmp/tnef.$$");
+    system("rm -rf $tempdir");
     return 1 if MailScanner::Config::Value('deliverunparsabletnef',$message);
     return 0;
   }
@@ -207,10 +225,12 @@ sub InternalDecoder {
 # This can't setup file2parent as it doesn't know the name of the children.
 # New - Unpack it into a subdirectory so we don't have name clashes anywhere.
 sub ExternalDecoder {
-  my($dir, $tnefname, $message) = @_;
+  my($dir, $tnefname, $message, $perms, $owner, $group, $change) = @_;
 
   # Create the subdir to unpack it into
-  my $unpackdir = "tnef.$$";
+  #my $unpackdir = "tnef.$$";
+  my ($tmpfh, $unpackdir) = tempfile("tnefXXXXXX", TMPDIR => $dir, UNLINK => 0);
+  $dir =~ s,^.*/,,;
   $unpackdir = $message->MakeNameSafe($unpackdir, $dir);
   unless (mkdir "$dir/$unpackdir", 0777) {
     MailScanner::Log::WarnLog("Trying to unpack %s in message %s, could not create subdirectory %s, failed to unpack TNEF message", $tnefname, $message->{id},
@@ -295,9 +315,23 @@ sub ExternalDecoder {
       return 0 unless defined $dirh;
       while (defined(my $unpacked = $dirh->read)) {
         next unless -f "$dir/$unpackdir/$unpacked";
-        my $safe = $message->MakeNameSafe($unpacked, $dir);
+        # Add a 't' to the safename to mark it as a tnef member.
+        my $safe = $message->MakeNameSafe('t'.$unpacked, $dir);
+        # This will cause big problems as $safe has a type, and shouldn't!
+        $message->{file2parent}{$safe} = $tnefname;
+        my $name1 = "$dir/$unpackdir/$unpacked";
+        $name1 =~ /(.*)/;
+        $name1 = $1;
+        my $name2 = "$dir/$safe";
+        $name2 =~ /(.*)/;
+        $name2 = $1;
+        rename $name1, $name2;
+        # JKF 20090421 CHMOD, then CHOWN and CHGRP it if necessary.
+        chmod $perms, $name2;
+        chown $owner, $group, $name2 if $change;
+        # So let's remove the type indicator from $safe and store that too :)
+        $safe =~ s#^(.*/)([^/])([^/]+)$#$1$3#; # I assert $2 will equal 't'.
         $message->{file2parent}{$safe} = $tnefname;
-        rename "$dir/$unpackdir/$unpacked", "$dir/$safe";
       }
       rmdir "$dir/$unpackdir"; # Directory should be empty now
       return 1;
@@ -312,15 +346,29 @@ sub ExternalDecoder {
     while (defined($unpacked = $dirh->read)) {
       #print STDERR "Directory entry is \"$unpacked\" in \"$dir/$unpackdir\"\n";
       next unless -f "$dir/$unpackdir/$unpacked";
-      $safename = $message->MakeNameSafe($unpacked, $dir);
+      # Add a 't' to the safename to mark it as a tnef member.
+      $safename = $message->MakeNameSafe('t'.$unpacked, $dir);
       if (/^msg[\d-]+\.txt$/) {
         ($type, $encoding) = ("text/plain", "8bit");
       } else {
         ($type, $encoding) = ("application/octet-stream", "base64");
       }
       #print STDERR "Renaming '$dir/$unpackdir/$unpacked' to '$dir/$safename'\n";
-      rename "$dir/$unpackdir/$unpacked", "$dir/$safename";
+      my $oldname = "$dir/$unpackdir/$unpacked";
+      my $newname = "$dir/$safename";
+      $oldname =~ /^(.*)$/;
+      $oldname = $1;
+      $newname =~ /^(.*)$/;
+      $newname = $1;
+      rename $oldname, $newname;
+      #rename "$dir/$unpackdir/$unpacked", "$dir/$safename";
+      # JKF 20090421 CHMOD, then CHOWN and CHGRP it if necessary.
+      chmod $perms, $newname;
+      #chmod $perms, "$dir/$safename";
+      chown $owner, $group, $newname if $change;
+      #chown $owner, $group, "$dir/$safename" if $change;
       # The only file that ever existed in the message structure is the safename
+      $message->{file2parent}{substr($safename,1)} = $tnefname;
       $message->{file2parent}{$safename} = $tnefname;
       push @replacements, $safename;
       $message->{entity}->attach(Type => $type,
